Unit INFRVar;
{$O+}
{$F+}

INTERFACE
(*****************************************************************************)
(*>                                                                         <*)
(*>                   INFERNO Bulletin Board System Listing                 <*)
(*>           Copyright 1996 by Gili Tzabari. All rights reserved.          <*)
(*>                                                                         <*)
(*>                      Data types and structures                          <*)
(*>                                                                         <*)
(*****************************************************************************)
(*****************************************************************************)
(* ------------- IMPORTANT NOTICE -- PLEASE READ CAREFULLY ----------------- *)
(*****************************************************************************)

{                                                       January 1st, 1997

   Note to all INFERNO developers:

   These structures are the final release structures for INFERNO v1.1.

   These structures may be used to modify and create new programs which
   will be compatible with INFERNO v1.1.

   The structures have been commented as best as possible.  If you need
   more information on how to use/access data within these structures,
   please see the accompanying documentation for contact methods.

   Thanks for your interest in INFERNO v1.1.  Utility developers who wish
   more information regarding distribution should look at the accompanying
   documentation -- there are several helpful areas which should be read.

   We can use all the questions, comments and ideas that you can think of.

   Thanks,
   INFERNO v1.1 Development Team
}

(*****************************************************************************)
(* -------------------------- MODULE STRUCTURES ---------------------------- *)
(*****************************************************************************)

{

   Offset   Description                                              Length
           
   0        File Signature (should be 'INFR')                       4 bytes
   4        Version of Module File                                  2 bytes

                      Version of module (composed of 2 bytes)
                      

            0001 0010  0011 0100
                
                            4 Least Significant Bits of bit 2 = 4h = 4
                        4 Most  Significant Bits of bit 2 = 3h = 3
                   4 Least Significant Bits of bit 1 = 2h = 2
              4 Most  Significant Bits of bit 1 = 1h = 1

            The first 8 bits represent the major version
            The next  4 bits represent the minor version
            The next  4 bits represent the beta version

            Currently 1234h means "version 12.3 eta 4"

   6       Fading sequence                                        12 bytes

            Defines 4 palette settings which are used for fading prompts.
            Prompts will fade from first palette setting to the second and
            vice versa.

   18       Palette settings                                       96 bytes

            Palette settings to be used within INFERNO. When entering
            different menus (ie: overview menu) INFERNO will load
            this saved palette and use it to draw the screen. Defaults are
            available further down as CONSTants with further explanations.

   114      First BBS Data Entry                                  146 bytes

   BBS Data Entries have the following format:

   Offset   Description                                              Length
           
   0        Name of BBS                                            31 bytes
   31       BBS Phone Number                                        6 bytes
   37       Computer Type                                           1 byte

            Computer Type stores the type of CPU and Operating System used
            by the BBS. The 4 LSBs are used for CPU type and the 4 MSBs are
            used for the Operating System:

            CPU Types:

            0 = Unknown
            1 = 8086/8088
            2 = 286
            3 = 386SX/DX
            4 = 486DX
            5 = 486DX2/DX4
            6 = Pentium
            7 = Pentium Pro
            8 = Pentium+
            9 = Amiga
            10 = Atari or Commodore
            11 = Macintosh
            12 = PowerPC
            13 to 15 = Future Use

            Operating Systems:

            0 = Unknown
            1 = DOS
            2 = Desqview
            3 = OS/2
            4 = Windows
            5 = Unix/Linux/etc
            6 = MacOS
            7 to 15 = Future Use

   38       Modem Speed                                             1 byte

            Values for the speed of the modem used are:

            0 = Unknown
            1 = 300 bps
            2 = 1200 bps
            3 = 2400 bps
            4 = 4800 bps
            5 = 9600 bps
            6 = 14,400 bps
            7 = 19,200 bps
            8 = 21,600 bps
            9 = 28,800 bps
            10 = 33,600 bps
            255 = ISDN Line

   39       BBS Rating                                              1 byte

            This unsigned value between 0 and 100 indicates the quality of
            the BBS as judged by official voters. A value of 255 indicates
            rating is not available.

   40       Cost                                                    1 byte

            0 = It does not costs to be a validated user.
            1 = It does.

   41       Description (written by the SysOp)                     79 bytes
   120      BBS Software                                            1 byte

             0 = Unknown
             1 = Adaptek
             2 = Auntie
             3 = C-Net Pro
             4 = Command Processor (C.P.) tm
             5 = DLX
             6 = EXCELSIOR! Pro
             7 = FirstClass
             8 = GT Power
             9 = Hermes II
            10 = Iniquity
            11 = Lora
            12 = Major BBS
            13 = Maximus
            14 = Oblivion
            15 = PCBoard
            16 = PowerBoard
            17 = ProBoard
            18 = Remote Access
            19 = Renegade
            20 = RoboBoard/FX
            21 = SearchLight
            22 = Spitfire
            23 = Synchronet
            24 = The Bread Board System
            25 = Telegard
            26 = TurBoard
            27 = Wildcat!
            28 = WWIV

   121      SysOp's name (or alias)                                21 bytes
   142      Date of last update/verification of information         4 bytes

   Note:  LSB and MSB mean Least and Most Significant Bit. The reference to
          4 LSBs and MSBs are the upper and lower halves of the byte:

           Example:

           63 = 3Fh =   0011 1111
                         
                               4 Least Significant Bits = Fh = 15
                          4 Most Significant Bits = 3h = 3

                                              -Shiva [coder/ShadowCraft]
}

(*****************************************************************************)
(* ------------------------ CONSTANT DEFINITIONS --------------------------- *)
(*****************************************************************************)
CONST Version = $0101;                           {Version number}
      ReleaseDate = '[o1/o2/97]';                {Release date}
      ModuleName = 'INFERNO.DAT';                {Module filename}
      ScreenSize = 23;                           {Screen size}
      ColumnMax = 6;                             {Number of existing columns}
      BBSStat = 10000000000.0;                   {Online/Offline BBS status
                                                  is determined by checking
                                                  if the phone number is
                                                  less or greater than this
                                                  value (respectively)
                                                 }
      MenuHeader : String[7] = 'menudat';        {Header preceeding menus}
      MenuSize = 16000;                          {Size of menus}

      Colors : ARRAY[0..1, 0..13] Of Byte =
        (                                      {Fading mode}
         ($01,                                    {TextAttr of border}
          $04,                                    {TextAttr of records}
          $3B,                                    {TextAttr of selection bar}
          $0F,                                    {TextAttr of SEARCHKEYs}
          $0F,                                    {TextAttr of titles}
          $0E,                                    {TextAttr of selected title}
          $0F,                                    {TextAttr of tagging symbol}
          $0D,                                    {TextAttr of DETAILED MENU border}
          $05,                                    {TextAttr of DETAILED MENU windows}
          $0D,                                    {TextAttr of DETAILED MENU output}
          $01,                                    {TextAttr of DETAILED MENU rating border}
          $01,                                    {TextAttr of DETAILED MENU rating bar}
          $0E,                                    {TextAttr of DETAILED MENU tag indicator}
          $06),                                   {TextAttr of fading prompt}

                                               {Multitasking mode}
         ($01,                                    {TextAttr of border}
          $04,                                    {TextAttr of records}
          $3B,                                    {TextAttr of selection bar}
          $0F,                                    {TextAttr of SEARCHKEYs}
          $0F,                                    {TextAttr of titles}
          $0E,                                    {TextAttr of selected title}
          $0F,                                    {TextAttr of tagging symbol}
          $0D,                                    {TextAttr of DETAILED MENU border}
          $05,                                    {TextAttr of DETAILED MENU windows}
          $0D,                                    {TextAttr of DETAILED MENU output}
          $01,                                    {TextAttr of DETAILED MENU rating border}
          $01,                                    {TextAttr of DETAILED MENU rating bar}
          $0E,                                    {TextAttr of DETAILED MENU tag indicator}
          $06)                                    {TextAttr of fading prompt}
              );

      FadeSequence : ARRAY[0..3, 0..2] Of 0..63 = {Colors used for fading prompt}
        (
         (63, 63, 63),                           {Starting color  HELP prompt}
         ( 0,  0,  0),                           {Ending color    HELP prompt}
         (47, 63, 06),                           {Starting color  RECORDS}
         (35, 39, 31)                            {Ending color    RECORDS}
                     );

      Palette : ARRAY[0..1, 0..15, 0..2] Of 0..63 = {Palette settings for menus}
        (
         (                                       {Overview menu}
          ( 0,  0,  0),                             {Black}
          ( 0,  0, 42),                             {Blue}
          (63, 63, 63),                             {Green  MODIFIED}
          ( 0, 42, 42),                             {Cyan  MODIFIED}
          ( 1, 30, 55),                             {Red  MODIFIED}
          (42,  0, 42),                             {Magenta}
          (63, 63, 63),                             {Brown}
          (42, 42, 42),                             {LightGray}
          (21, 21, 21),                             {DarkGray}
          (21, 21, 63),                             {LightBlue}
          (21, 63, 21),                             {LightGreen}
{47,63,6} (21, 63, 63),                             {LightCyan  MODIFIED}
          (63, 21, 21),                             {LightRed}
          (63, 21, 63),                             {LightMagenta}
          (63, 63, 21),                             {Yellow}
          (63, 63, 63)                              {White}
                      ),
         (                                       {Detailed menu}
          ( 0,  0,  0),                             {Black}
          (19, 37, 47),                             {Blue  MODIFIED}
          ( 0, 42,  0),                             {Green}
          ( 0, 42, 42),                             {Cyan}
          (42,  0,  0),                             {Red}
          (63, 30, 62),                             {Magenta  MODIFIED}
          (63, 63, 63),                             {Brown}
          (42, 42, 42),                             {LightGray}
          (21, 21, 21),                             {DarkGray}
          (21, 21, 63),                             {LightBlue}
          (21, 63, 21),                             {LightGreen}
          (21, 63, 63),                             {LightCyan}
          (63, 21, 21),                             {LightRed}
          (58, 42, 62),                             {LightMagenta  MODIFIED}
          (63, 63, 21),                             {Yellow}
          (63, 63, 63)                              {White}
                      )
                       );

      Comp_Type : ARRAY[0..12] Of String[18] =   {Computers supported}
        ('Unknown',
         '8086/8088',
         '286',
         '386SX/DX',
         '486DX',
         '486DX2/DX4',
         'Pentium',
         'Pentium Pro',
         'Pentium+',
         'Amiga',
         'Atari or Commodore',
         'Macintosh',
         'PowerPC');

      OS_Type : ARRAY[0..6] Of String[15] =      {Operating systems supported}
        ('Unknown',
         'DOS',
         'Desqview',
         'OS/2',
         'Windows',
         'Unix/Linux/etc',
         'MacOS');

      BBS_Type : ARRAY[0..28] Of String[27] =    {BBSs supported}
        ('Unknown',
         'Adaptek',
         'Auntie',
         'C-Net Pro',
         'Command Processor (C.P.) tm',
         'DLX',
         'EXCELSIOR! Pro',
         'FirstClass',
         'GT Power',
         'Hermes II',
         'Iniquity',
         'Lora',
         'Major BBS',
         'Maximus',
         'Oblivion',
         'PCBoard',
         'PowerBoard',
         'ProBoard',
         'Remote Access',
         'Renegade',
         'RoboBoard/FX',
         'SearchLight',
         'Spitfire',
         'Synchronet',
         'The Bread Board System',
         'Telegard',
         'TurBoard',
         'Wildcat!',
         'WWIV');

      Modem_Speed : ARRAY[0..11] Of String[9] =  {Modem speeds supported}
        ('Unknown',
         '300',
         '1200',
         '2400',
         '4800',
         '9600',
         '14,400',
         '19,200',
         '21,600',
         '28,800',
         '33,600',
         'ISDN Line');

      Rate_Type : String[10] = ('');   {Rating string, rating out of 10}

      Cost_Type : ARRAY[0..1] Of String[10] =    {Cost string}
        ('Free BBS', 'Paying BBS');

      ColumnPos : ARRAY[1..ColumnMax] of Byte =  {Beginning of each column, X coordinate}
        (2, 24, 39, 58, 68, 79);

(*****************************************************************************)
(* -------------------------- TYPE DEFINITIONS ----------------------------- *)
(*****************************************************************************)

TYPE CacheNode = ^CacheElement;    {Pointer of CacheElement}

     CacheRec = RECORD               {Cache record, used to speed up scrolling}
       Name : String[21];
       Phone : Real;
       Computer,
       Speed,
       Rating : Byte;
       Cost,
       Tagged : Boolean;             {Record is tagged}
       Link : Word;                  {Links a cache element to a record in the module file}
     END; {Cache Record}

     CacheElement = RECORD           {Cache element, used to process cache records}
       Data : CacheRec;
       Next, Last : CacheNode;
     END; {Cache Element}

(*****************************************************************************)
(* -------------------------- DATA STRUCTURES ------------------------------ *)
(*****************************************************************************)

     Module_Hdr = RECORD
       Signature : ARRAY[0..3] Of Char;   {Signature}
       Version   : Word;                  {Version}
       FadeSequence : ARRAY[0..3, 0..2] Of 0..63;    {Colors used for fading}
       Palette : ARRAY[0..1, 0..15, 0..2] Of 0..63;  {Palette settings for menus}
     END; {Module header}

     Module_Rec = RECORD              {Module record, used for module file structure}
       Name : ARRAY[0..30] of Char;   {BBS name}
       Phone : Real;                  {BBS number, packed into REAL.
                                       Each digit represents phone digit,
                                       (ie: 5143318158.0 would be 514-331-8158)

                                       Digit #11 indicates BBS status: (hence the BBSStat variable)
                                         0 - Normal status
                                         1 - BBS is down}
       Computer,                      {Computer/OS type}
       Speed,                         {Modem speed}
       Rating : Byte;                 {Rating out of 100, 255 indicates N/A}
       Cost : Boolean;                {Cost of BBSing}
       {DETAILED DESCRIPTION-}
       Description : ARRAY[0..78] of Char; {Description of BBS by sysop}
       BBSType : Byte;                     {BBS type}
       Sysop : ARRAY[0..20] of Char;       {Sysop name}
       LastUpdate : LongInt;               {Date of last update}
     END; {Module Record}

IMPLEMENTATION
END.